cargo-winapp-0.1.1 is not a library.
cargo-winapp
Cargo subcommand for Windows app development with winapp.
Simplifies winapp CLI usage by automatically handling Cargo build artifacts, eliminating the need to manually specify executable paths.
Prerequisites
- winapp CLI: Required. This plugin acts as a wrapper for the
winappcommand, so it must be installed to function.winget install microsoft.winappcli --source winget
Installation
Usage
Build
Builds and applies identity without running (useful for debugging).
Run
Builds the app, applies a debug identity, and runs it.
Pack
Packages the application into an .msix bundle for distribution.
License
MIT